package com.inspect.system.service;

import com.inspect.system.base.domain.SysDictData;
import com.inspect.system.base.domain.SysDictType;

import java.util.List;

public interface ISysDictTypeService {
    List<SysDictType> selectDictTypeList(SysDictType sysDictType);

    List<SysDictType> selectDictTypeAll();

    List<SysDictData> selectDictDataByType(String dictType);

    SysDictType selectDictTypeById(Long dictId);

    SysDictType selectDictTypeByType(String dictType);

    void deleteDictTypeByIds(Long[] dictIds);

    void loadingDictCache();

    void clearDictCache();

    void resetDictCache();

    int insertDictType(SysDictType sysDictType);

    int updateDictType(SysDictType sysDictType);

    String checkDictTypeUnique(SysDictType sysDictType);
}
